@@ -1,87 +1,90 @@
-/* Interface to `ar' archives for GNU Make.
-Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997,
-1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Free Software
-Foundation, Inc.
+/* Interface to 'ar' archives for GNU Make.
+Copyright (C) 1988-2013 Free Software Foundation, Inc.
+
 This file is part of GNU Make.
 
 GNU Make is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
-Foundation; either version 2, or (at your option) any later version.
+Foundation; either version 3 of the License, or (at your option) any later
+version.
 
 GNU Make is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along with
-GNU Make; see the file COPYING.  If not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.  */
+this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#include "make.h"
+#include "makeint.h"
 
-#ifndef	NO_ARCHIVES
+#ifndef NO_ARCHIVES
 
 #include "filedef.h"
 #include "dep.h"
 #include <fnmatch.h>
 
-/* Defined in arscan.c.  */
-extern long int ar_scan PARAMS ((char *archive, long int (*function) (), long int arg));
-extern int ar_name_equal PARAMS ((char *name, char *mem, int truncated));
-#ifndef VMS
-extern int ar_member_touch PARAMS ((char *arname, char *memname));
-#endif
-
-/* Return nonzero if NAME is an archive-member reference, zero if not.
-   An archive-member reference is a name like `lib(member)'.
-   If a name like `lib((entry))' is used, a fatal error is signaled at
+/* Return nonzero if NAME is an archive-member reference, zero if not.  An
+   archive-member reference is a name like 'lib(member)' where member is a
+   non-empty string.
+   If a name like 'lib((entry))' is used, a fatal error is signaled at
    the attempt to use this unsupported feature.  */
 
 int
-ar_name (char *name)
+ar_name (const char *name)
 {
-  char *p = strchr (name, '(');
-  char *end;
+  const char *p = strchr (name, '(');
+  const char *end;
 
   if (p == 0 || p == name)
     return 0;
 
   end = p + strlen (p) - 1;
-  if (*end != ')')
+  if (*end != ')' || end == p + 1)
     return 0;
 
   if (p[1] == '(' && end[-1] == ')')
-    fatal (NILF, _("attempt to use unsupported feature: `%s'"), name);
+    fatal (NILF, _("attempt to use unsupported feature: '%s'"), name);
 
   return 1;
 }
 
 
 /* Parse the archive-member reference NAME into the archive and member names.
-   Put the malloc'd archive name in *ARNAME_P if ARNAME_P is non-nil;
-   put the malloc'd member name in *MEMNAME_P if MEMNAME_P is non-nil.  */
+   Creates one allocated string containing both names, pointed to by ARNAME_P.
+   MEMNAME_P points to the member.  */
 
 void
-ar_parse_name (char *name, char **arname_p, char **memname_p)
+ar_parse_name (const char *name, char **arname_p, char **memname_p)
 {
-  char *p = strchr (name, '('), *end = name + strlen (name) - 1;
+  char *p;
 
-  if (arname_p != 0)
-    *arname_p = savestring (name, p - name);
-
-  if (memname_p != 0)
-    *memname_p = savestring (p + 1, end - (p + 1));
+  *arname_p = xstrdup (name);
+  p = strchr (*arname_p, '(');
+  *(p++) = '\0';
+  p[strlen (p) - 1] = '\0';
+  *memname_p = p;
 }
 
-static long int ar_member_date_1 PARAMS ((int desc, char *mem, int truncated, long int hdrpos,
-	long int datapos, long int size, long int date, int uid, int gid, int mode, char *name));
+
+/* This function is called by 'ar_scan' to find which member to look at.  */
+
+/* ARGSUSED */
+static long int
+ar_member_date_1 (int desc UNUSED, const char *mem, int truncated,
+                  long int hdrpos UNUSED, long int datapos UNUSED,
+                  long int size UNUSED, long int date,
+                  int uid UNUSED, int gid UNUSED, int mode UNUSED,
+                  const void *name)
+{
+  return ar_name_equal (name, mem, truncated) ? date : 0;
+}
 
 /* Return the modtime of NAME.  */
 
 time_t
-ar_member_date (char *name)
+ar_member_date (const char *name)
 {
   char *arname;
-  int arname_used = 0;
   char *memname;
   long int val;
 
@@ -98,126 +101,102 @@ ar_member_date (char *name)
     struct file *arfile;
     arfile = lookup_file (arname);
     if (arfile == 0 && file_exists_p (arname))
-      {
-	arfile = enter_file (arname);
-	arname_used = 1;
-      }
+      arfile = enter_file (strcache_add (arname));
 
     if (arfile != 0)
       (void) f_mtime (arfile, 0);
   }
 
-  val = ar_scan (arname, ar_member_date_1, (long int) memname);
+  val = ar_scan (arname, ar_member_date_1, memname);
 
-  if (!arname_used)
-    free (arname);
-  free (memname);
+  free (arname);
 
   return (val <= 0 ? (time_t) -1 : (time_t) val);
 }
-
-/* This function is called by `ar_scan' to find which member to look at.  */
-
-/* ARGSUSED */
-static long int
-ar_member_date_1 (int desc UNUSED, char *mem, int truncated,
-		  long int hdrpos UNUSED, long int datapos UNUSED,
-                  long int size UNUSED, long int date,
-                  int uid UNUSED, int gid UNUSED, int mode UNUSED, char *name)
-{
-  return ar_name_equal (name, mem, truncated) ? date : 0;
-}
 
 /* Set the archive-member NAME's modtime to now.  */
 
 #ifdef VMS
 int
-ar_touch (char *name)
+ar_touch (const char *name)
 {
   error (NILF, _("touch archive member is not available on VMS"));
   return -1;
 }
 #else
 int
-ar_touch (char *name)
+ar_touch (const char *name)
 {
   char *arname, *memname;
-  int arname_used = 0;
-  register int val;
+  int val;
 
   ar_parse_name (name, &arname, &memname);
 
   /* Make sure we know the modtime of the archive itself before we
-     touch the member, since this will change the archive itself.  */
+     touch the member, since this will change the archive modtime.  */
   {
     struct file *arfile;
-    arfile = lookup_file (arname);
-    if (arfile == 0)
-      {
-	arfile = enter_file (arname);
-	arname_used = 1;
-      }
-
-    (void) f_mtime (arfile, 0);
+    arfile = enter_file (strcache_add (arname));
+    f_mtime (arfile, 0);
   }
 
   val = 1;
   switch (ar_member_touch (arname, memname))
     {
     case -1:
-      error (NILF, _("touch: Archive `%s' does not exist"), arname);
+      error (NILF, _("touch: Archive '%s' does not exist"), arname);
       break;
     case -2:
-      error (NILF, _("touch: `%s' is not a valid archive"), arname);
+      error (NILF, _("touch: '%s' is not a valid archive"), arname);
       break;
     case -3:
       perror_with_name ("touch: ", arname);
       break;
     case 1:
       error (NILF,
-             _("touch: Member `%s' does not exist in `%s'"), memname, arname);
+             _("touch: Member '%s' does not exist in '%s'"), memname, arname);
       break;
     case 0:
       val = 0;
       break;
     default:
       error (NILF,
-             _("touch: Bad return code from ar_member_touch on `%s'"), name);
+             _("touch: Bad return code from ar_member_touch on '%s'"), name);
     }
 
-  if (!arname_used)
-    free (arname);
-  free (memname);
+  free (arname);
 
   return val;
 }
 #endif /* !VMS */
 
-/* State of an `ar_glob' run, passed to `ar_glob_match'.  */
+/* State of an 'ar_glob' run, passed to 'ar_glob_match'.  */
 
 struct ar_glob_state
   {
-    char *arname;
-    char *pattern;
+    const char *arname;
+    const char *pattern;
     unsigned int size;
     struct nameseq *chain;
     unsigned int n;
   };
 
-/* This function is called by `ar_scan' to match one archive
+/* This function is called by 'ar_scan' to match one archive
    element against the pattern in STATE.  */
 
 static long int
-ar_glob_match (int desc UNUSED, char *mem, int truncated UNUSED,
-	       long int hdrpos UNUSED, long int datapos UNUSED,
+ar_glob_match (int desc UNUSED, const char *mem, int truncated UNUSED,
+               long int hdrpos UNUSED, long int datapos UNUSED,
                long int size UNUSED, long int date UNUSED, int uid UNUSED,
-               int gid UNUSED, int mode UNUSED, struct ar_glob_state *state)
+               int gid UNUSED, int mode UNUSED, const void *arg)
 {
+  struct ar_glob_state *state = (struct ar_glob_state *)arg;
+
   if (fnmatch (state->pattern, mem, FNM_PATHNAME|FNM_PERIOD) == 0)
     {
       /* We have a match.  Add it to the chain.  */
-      struct nameseq *new = (struct nameseq *) xmalloc (state->size);
-      new->name = concat (state->arname, mem, ")");
+      struct nameseq *new = xcalloc (state->size);
+      new->name = strcache_add (concat (4, state->arname, "(", mem, ")"));
       new->next = state->chain;
       state->chain = new;
       ++state->n;
@@ -232,28 +211,28 @@ static int
 glob_pattern_p (const char *pattern, int quote)
 {
   const char *p;
-  int open = 0;
+  int opened = 0;
 
   for (p = pattern; *p != '\0'; ++p)
     switch (*p)
       {
       case '?':
       case '*':
-	return 1;
+        return 1;
 
       case '\\':
-	if (quote)
-	  ++p;
-	break;
+        if (quote)
+          ++p;
+        break;
 
       case '[':
-	open = 1;
-	break;
+        opened = 1;
+        break;
 
       case ']':
-	if (open)
-	  return 1;
-	break;
+        if (opened)
+          return 1;
+        break;
       }
 
   return 0;
@@ -263,11 +242,11 @@ glob_pattern_p (const char *pattern, int quote)
    Return a malloc'd chain of matching elements (or nil if none).  */
 
 struct nameseq *
-ar_glob (char *arname, char *member_pattern, unsigned int size)
+ar_glob (const char *arname, const char *member_pattern, unsigned int size)
 {
   struct ar_glob_state state;
-  char **names;
   struct nameseq *n;
+  const char **names;
   unsigned int i;
 
   if (! glob_pattern_p (member_pattern, 1))
@@ -275,28 +254,25 @@ ar_glob (char *arname, char *member_pattern, unsigned int size)
 
   /* Scan the archive for matches.
      ar_glob_match will accumulate them in STATE.chain.  */
-  i = strlen (arname);
-  state.arname = (char *) alloca (i + 2);
-  bcopy (arname, state.arname, i);
-  state.arname[i] = '(';
-  state.arname[i + 1] = '\0';
+  state.arname = arname;
   state.pattern = member_pattern;
   state.size = size;
   state.chain = 0;
   state.n = 0;
-  (void) ar_scan (arname, ar_glob_match, (long int) &state);
+  ar_scan (arname, ar_glob_match, &state);
 
   if (state.chain == 0)
     return 0;
 
   /* Now put the names into a vector for sorting.  */
-  names = (char **) alloca (state.n * sizeof (char *));
+  names = alloca (state.n * sizeof (const char *));
   i = 0;
   for (n = state.chain; n != 0; n = n->next)
     names[i++] = n->name;
 
   /* Sort them alphabetically.  */
-  qsort ((char *) names, i, sizeof (*names), alpha_compare);
+  /* MSVC erroneously warns without a cast here.  */
+  qsort ((void *)names, i, sizeof (*names), alpha_compare);
 
   /* Put them back into the chain in the sorted order.  */
   i = 0;
@@ -306,4 +282,4 @@ ar_glob (char *arname, char *member_pattern, unsigned int size)
   return state.chain;
 }
 
-#endif	/* Not NO_ARCHIVES.  */
+#endif  /* Not NO_ARCHIVES.  */
