@@ -18,11 +18,22 @@ this program.  If not, see <http://www.gnu.org/licenses/>.  */
 #include "gnumake.h"
 
 #include "debug.h"
+#include "filedef.h"
 #include "dep.h"
 #include "variable.h"
 
 #include <libguile.h>
 
+/* Pre-2.0 versions of Guile don't have a typedef for gsubr function types.  */
+#if SCM_MAJOR_VERSION < 2
+# define GSUBR_TYPE         SCM (*) ()
+/* Guile 1.x doesn't really support i18n.  */
+# define EVAL_STRING(_s)    scm_c_eval_string (_s)
+#else
+# define GSUBR_TYPE         scm_t_subr
+# define EVAL_STRING(_s)    scm_eval_string (scm_from_utf8_string (_s))
+#endif
+
 static SCM make_mod = SCM_EOL;
 static SCM obj_to_str = SCM_EOL;
 
@@ -71,10 +82,10 @@ guile_define_module (void *data UNUSED)
 #include "gmk-default.h"
 
   /* Register a subr for GNU make's eval capability.  */
-  scm_c_define_gsubr ("gmk-expand", 1, 0, 0, guile_expand_wrapper);
+  scm_c_define_gsubr ("gmk-expand", 1, 0, 0, (GSUBR_TYPE) guile_expand_wrapper);
 
   /* Register a subr for GNU make's eval capability.  */
-  scm_c_define_gsubr ("gmk-eval", 1, 0, 0, guile_eval_wrapper);
+  scm_c_define_gsubr ("gmk-eval", 1, 0, 0, (GSUBR_TYPE) guile_eval_wrapper);
 
   /* Define the rest of the module.  */
   scm_c_eval_string (GUILE_module_defn);
@@ -99,13 +110,22 @@ guile_init (void *arg UNUSED)
 static void *
 internal_guile_eval (void *arg)
 {
-  return cvt_scm_to_str (scm_c_eval_string (arg));
+  return cvt_scm_to_str (EVAL_STRING (arg));
 }
 
 /* This is the function registered with make  */
 static char *
-func_guile (const char *funcname UNUSED, int argc UNUSED, char **argv)
+func_guile (const char *funcname UNUSED, unsigned int argc UNUSED, char **argv)
 {
+  static int init = 0;
+
+  if (! init)
+    {
+      /* Initialize the Guile interpreter.  */
+      scm_with_guile (guile_init, NULL);
+      init = 1;
+    }
+
   if (argv[0] && argv[0][0] != '\0')
     return scm_with_guile (internal_guile_eval, argv[0]);
 
@@ -119,11 +139,8 @@ func_guile (const char *funcname UNUSED, int argc UNUSED, char **argv)
 int
 guile_gmake_setup (const gmk_floc *flocp UNUSED)
 {
-  /* Initialize the Guile interpreter.  */
-  scm_with_guile (guile_init, NULL);
-
   /* Create a make function "guile".  */
-  gmk_add_function ("guile", func_guile, 0, 1, 1);
+  gmk_add_function ("guile", func_guile, 0, 1, GMK_FUNC_DEFAULT);
 
   return 1;
 }
