@@ -18,8 +18,8 @@ this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include <assert.h>
 
-#include "dep.h"
 #include "filedef.h"
+#include "dep.h"
 #include "job.h"
 #include "commands.h"
 #include "variable.h"
@@ -803,6 +803,7 @@ define_automatic_variables (void)
            (remote_description == 0 || remote_description[0] == '\0')
            ? "" : remote_description);
   define_variable_cname ("MAKE_VERSION", buf, o_default, 0);
+  define_variable_cname ("MAKE_HOST", make_host, o_default, 0);
 
 #ifdef  __MSDOS__
   /* Allow to specify a special shell just for Make,
@@ -1418,7 +1419,7 @@ parse_variable_definition (const char *p, struct variable *var)
       int c = *p++;
 
       /* If we find a comment or EOS, it's not a variable definition.  */
-      if (c == '\0' || c == '#')
+      if (STOP_SET (c, MAP_COMMENT|MAP_NUL))
         return NULL;
 
       if (c == '$')
